@@ -2,6 +2,8 @@ ccor <- function(x, y) {
 
   x = as.matrix(x)
   y = as.matrix(y)
+  d <- min(ncol(x),ncol(y))
+
   cov.x.inv = solve(cov(x))
   cov.y.inv = solve(cov(y))
   cov.xy = cov(x,y)
@@ -9,7 +11,7 @@ ccor <- function(x, y) {
   x.eig = eigen(cov.x.inv %*% cov.xy %*% cov.y.inv %*% cov.yx)
   y.eig = eigen(cov.y.inv %*% cov.yx %*% cov.x.inv %*% cov.xy)
 
-  list(cancor = sqrt(x.eig$values),
-       xcoef = x.eig$vectors,
-       ycoef = y.eig$vectors)
+  list(cancor = sqrt(x.eig$values[1:d]),
+       xcoef = x.eig$vectors[,1:d],
+       ycoef = y.eig$vectors[,1:d])
 }
